.. qnum::
   :prefix: 3-9-
   :start: 1

Toggle Mixed Up or Write Code Practice
=========================================================

 For each of the problems below, if you need help, you can pull down the toggle menu to choose the associated mixed up code problem to help you get started.

For the mixed up code problems, drag the blocks into the correct order. Click the *Check Me* button to check each solution.  You will be told if your solution is too short, has a block in the wrong order, or you are using the wrong block.  Some of the problems may have an extra block that isn't needed in the correct solution. After 3 tries, you can ask for help and some of the blocks will be combined. You can solve these on your phone or other mobile device!

.. selectquestion:: select_u3_muc_wc1
   :fromid: u3_muc_wc1, ch5ex1muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc2
   :fromid: u3_muc_wc2, ch5ex2muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc3
   :fromid: u3_muc_wc3, ch5ex3muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc4
   :fromid: u3_muc_wc4, ch5ex4muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc5
   :fromid: u3_muc_wc5, ch5ex5muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc6
   :fromid: u3_muc_wc6, ch5ex6muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc7
   :fromid: u3_muc_wc7, ch5ex7muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc8
   :fromid: u3_muc_wc8, ch5ex8muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc9
   :fromid: u3_muc_wc9, ch5ex9muc
   :toggle: lock

.. selectquestion:: select_u3_muc_wc10
   :fromid: u3_muc_wc10, ch5ex10muc
   :toggle: lock


